==> hs-test-framework-0.6_1.tbz: lib/ghc-7.4.1/cabal/test-framework-0.6/register.sh <==
#!/bin/sh
echo 'name: test-framework
version: 0.6
id: test-framework-0.6-10f65e53ad35b6e1ee4c301f19eb38d8

license: BSD3
copyright:
maintainer: Max Bolingbroke <batterseapower@hotmail.com>
stability:
homepage: http://batterseapower.github.com/test-framework/
package-url:
synopsis: Framework for running and organising tests, with HUnit and QuickCheck support
description: Allows tests such as QuickCheck properties and HUnit test cases to be assembled into test groups, run in
             parallel (but reported in deterministic order, to aid diff interpretation) and filtered and controlled by
             command line options. All of this comes with colored test output, progress reporting and test statistics output.
category: Testing
author: Max Bolingbroke <batterseapower@hotmail.com>
exposed: True
exposed-modules: Test.Framework Test.Framework.Options
                 Test.Framework.Providers.API Test.Framework.Runners.Console
                 Test.Framework.Runners.Options Test.Framework.Seed
hidden-modules: Test.Framework.Core Test.Framework.Improving
                Test.Framework.Runners.Console.Colors
                Test.Framework.Runners.Console.ProgressBar
                Test.Framework.Runners.Console.Run
                Test.Framework.Runners.Console.Statistics
                Test.Framework.Runners.Console.Table
                Test.Framework.Runners.Console.Utilities
                Test.Framework.Runners.Core Test.Framework.Runners.Processors
                Test.Framework.Runners.Statistics
                Test.Framework.Runners.TestPattern
                Test.Framework.Runners.ThreadPool
                Test.Framework.Runners.TimedConsumption
                Test.Framework.Runners.XML.JUnitWriter Test.Framework.Runners.XML
                Test.Framework.Utilities
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/test-framework-0.6
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/test-framework-0.6
              /usr/local/lib
hs-libraries: HStest-framework-0.6
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: ansi-terminal-0.5.5-3c75c32b87d782c552a2534eedcfb485
         ansi-wl-pprint-0.6.4-a410a81a3a59e2eeb768700ae1f0fde6
         base-4.5.0.0-3459bca6d8e46666b517e8bb2e033728
         containers-0.4.2.1-cfc6420ecc2194c9ed977b06bdfd9e69
         extensible-exceptions-0.1.1.4-d27a1ac47e54880cae007cceceb41580
         hostname-1.0-f8064aa7c2dc842ecc0af88b780d2d8f
         old-locale-1.0.0.4-a2c3d942f886fb70df8171795fdc2e5a
         random-1.0.1.1-7f9342c90214b9289fdaf20c9e2f867f
         regex-posix-0.95.1-13e139edc671850b5c9286b396d4245e
         time-1.4-96b42dcaca5cdbc30bab9dcc07384b8d
         xml-1.3.12-8de6b90bf1403b0b1df00923b69ec262
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/test-framework-0.6/html/test-framework.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/test-framework-0.6/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-test-framework-0.8_2.tbz: lib/ghc-7.4.2/cabal/test-framework-0.8/register.sh <==
#!/bin/sh
echo 'name: test-framework
version: 0.8
id: test-framework-0.8-4d05afc672c103d916741e2b8849a989

license: BSD3
copyright:
maintainer: Max Bolingbroke <batterseapower@hotmail.com>
stability:
homepage: http://batterseapower.github.com/test-framework/
package-url:
synopsis: Framework for running and organising tests, with HUnit and QuickCheck support
description: Allows tests such as QuickCheck properties and HUnit test cases to be assembled into test groups, run in
             parallel (but reported in deterministic order, to aid diff interpretation) and filtered and controlled by
             command line options. All of this comes with colored test output, progress reporting and test statistics output.
category: Testing
author: Max Bolingbroke <batterseapower@hotmail.com>
exposed: True
exposed-modules: Test.Framework Test.Framework.Options
                 Test.Framework.Providers.API Test.Framework.Runners.Console
                 Test.Framework.Runners.Options Test.Framework.Seed
hidden-modules: Test.Framework.Core Test.Framework.Improving
                Test.Framework.Runners.Console.Colors
                Test.Framework.Runners.Console.ProgressBar
                Test.Framework.Runners.Console.Run
                Test.Framework.Runners.Console.Statistics
                Test.Framework.Runners.Console.Table
                Test.Framework.Runners.Console.Utilities
                Test.Framework.Runners.Core Test.Framework.Runners.Processors
                Test.Framework.Runners.Statistics
                Test.Framework.Runners.TestPattern
                Test.Framework.Runners.ThreadPool
                Test.Framework.Runners.TimedConsumption
                Test.Framework.Runners.XML.JUnitWriter Test.Framework.Runners.XML
                Test.Framework.Utilities
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/test-framework-0.8
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/test-framework-0.8
              /usr/local/lib
hs-libraries: HStest-framework-0.8
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: ansi-terminal-0.6-648cf1698c4a4e76a8187461c4376a8d
         ansi-wl-pprint-0.6.6-dacba4fafd06c8d59b43e8a3fb291878
         base-4.5.1.0-12fddc14a7babb909dd3843e453b5660
         containers-0.4.2.1-efa59805336a77490296ae3897cecb87
         extensible-exceptions-0.1.1.4-3d9bd197c43329612c640f24179a7f19
         hostname-1.0-1275a0ca77236572babdc116ce2069ce
         old-locale-1.0.0.4-b1d945ebea59a524cba400a524cb40aa
         random-1.0.1.1-fb8963ffa6ffa7a0a448fb912ed467a3
         regex-posix-0.95.2-d9fe86a76ffc5af4d3ed783956717b13
         time-1.4-b8e1c3d423daa1e2c5470a82caf23b52
         xml-1.3.12-ecec45be636a6384751be6d22fd7c163
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/test-framework-0.8/html/test-framework.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/test-framework-0.8/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
